==> gnue-reports_0.1.7.orig.tar.gz: gnue-reports-0.1.7/src/base/layout/GRField.py <==
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or (at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2004 Free Software Foundation
#
# FILE:
# GRLayout.py
#
# DESCRIPTION:
# Classes related to the Layout section
#
# NOTES:
#


from gnue.common.apps import GDebug
from gnue.common.datasources import GConditions
from gnue.common.logic.GTrigger import GTrigger,GTriggerExtension

import string
from xml.sax import saxutils
from GRLayoutElement import GRLayoutElement


############################################################
#
# <field> tag
#
class GRField (GRLayoutElement):
  def __init__(self, parent):
    GRLayoutElement.__init__(self, parent, 'GRField')
    self._section = None
    self.format = None

  def process(self, dest, mapper, isfirst, islast, firstSection, nextSection):
    ## structuralComment(dest,"<!-- [field:%s] -->" % self.name)
    dest.write (string.replace(saxutils.escape("%s" % self._mymapper.getField(self.name,
                                              self.format)), '\r','').encode(gConfig('textEncoding'),'replace'))
    ## structuralComment(dest,"<!-- [/field:%s] -->" % self.name)
    return nextSection

==> gnue-reports_0.1.8.orig.tar.gz: gnue-reports-0.1.8/src/base/layout/GRField.py <==
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or (at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2005 Free Software Foundation
#
# FILE:
# GRLayout.py
#
# DESCRIPTION:
# Classes related to the Layout section
#
# NOTES:
#


from gnue.common.apps import GDebug
from gnue.common.datasources import GConditions
from gnue.common.logic.GTrigger import GTrigger,GTriggerExtension

import string
from xml.sax import saxutils
from GRLayoutElement import GRLayoutElement


############################################################
#
# <field> tag
#
class GRField (GRLayoutElement):
  def __init__(self, parent):
    GRLayoutElement.__init__(self, parent, 'GRField')
    self._section = None
    self.format = None

    self._triggerFunctions={'get':{'function':self.getValue}}
    self._triggerGet = self.getValue
    self._triggerProperties = {'value':{'get':self.getValue }}
      

  def process(self, dest, mapper, isfirst, islast, firstSection, nextSection):
    ## structuralComment(dest,"<!-- [field:%s] -->" % self.name)
    dest.write (string.replace(saxutils.escape("%s" % self._mymapper.getField(self.name,
                                              self.format)), '\r','').encode(gConfig('textEncoding'),'replace'))
    ## structuralComment(dest,"<!-- [/field:%s] -->" % self.name)
    return nextSection


  ####################################################################
  #
  # Trigger functions
  #
  def getValue(self):
    return self._mymapper.getField(self.name, self.format)
